/* GCompris - Menu.qml
 *
 * Copyright (C) 2014 Bruno Coudoin <bruno.coudoin@gcompris.net>
 *
 * Authors:
 *   Bruno Coudoin <bruno.coudoin@gcompris.net> (Qt Quick port)
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 3 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, see <http://www.gnu.org/licenses/>.
 */
import QtQuick 2.2
import "../../core"
import GCompris 1.0

ActivityBase {
    id: menuActivity
    focus: true
    activityInfo: ActivityInfoTree.rootMenu

    // @cond INTERNAL_DOCS
    property string url: "qrc:/gcompris/src/activities/menu/resource/"

    pageComponent: Rectangle {
        id: background
        width: parent.width

        function loadActivity() {
            pageView.push(activityLoader.item)
        }

        Loader {
            id: activityLoader
            asynchronous: true
            onStatusChanged: {
                print("new status: " + status)
                if (status == Loader.Ready) {
                    loadActivity()
                }
            }
            onSourceChanged: print("new source: " + source)
        }

        Item {
            id: delegateItem
            width: 250
            height: 250
            Image {
                id: activityBackground
                source: "qrc:/gcompris/src/activities/test/test.svg";
                anchors.horizontalCenter: parent.horizontalCenter
                sourceSize.height: 250
                anchors.margins: 5
            }
            MouseArea {
                anchors.fill: activityBackground
                onClicked: {
                    if(pageView.busy) return

                    print("audio: " + audio)

                    activityLoader.setSource("qrc:/gcompris/src/activities/test/Test.qml",
                    {
                        // without plop, no crash
                        'audio': audio,
                        'menu': menuActivity,
                        'activityInfo': ActivityInfoTree.menuTree[0]
                    })
                    print("end select")
                    if (activityLoader.status == Loader.Ready) {
                        loadActivity()
                    }
                }
            }
        }
    }
}
